baseObjects.ObjectStore

|  | ## Cheshire3 Object Model: Class ObjectStore

Module baseObjects :: Class ObjectStore

## Class ObjectStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                           ObjectStore

Known Subclasses:
  DocumentStore, QueryStore, RecordStore, ResultSetStore, objectStore.BdbObjectStore

An interface to a persistent storage mechanism for configured Cheshire3 objects.
Instance Methods

create_object(self, session, object=None) Given a Cheshire3 object, create a serialised form of it in the database.
delete_object(self, session, id) Delete an object.
fetch_object(self, session, id) Fetch an object.
store_object(self, session, object) Store an object, potentially overwriting an existing copy.
Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### create_object(self, session, object=None) | source code
Given a Cheshire3 object, create a serialised form of it in the database. Note: You should use create_record() as per RecordStore to create an object from a configuration.

### delete_object(self, session, id) | source code
Delete an object.

### fetch_object(self, session, id) | source code
Fetch an object.

### store_object(self, session, object) | source code
Store an object, potentially overwriting an existing copy.